==> tools_doc_sphinx-0.1.0.tar.gz: tools_doc_sphinx-0.1.0/README.md <==
tools_doc_sphinx
================

**tools_doc_sphinx** is a package that provides functions for automatic generation of files used in Sphinx documentation :

* When documenting a Python package, generation of nested RST files with API reference,
* Generation of nested tree view of source code in a TXT file.


Documentation
-------------

Documentation is hosted on [ReadTheDocs](https://toolsdocsphinx.readthedocs.io/en/latest/index.html).


Installation
------------

**Pip**

The easiest way is to install **ViSiAnnoT** with ``pip``:

    $ pip install tools_doc_sphinx

You may need to call ``pip3`` instead.


**From source**

You may install **tools_doc_sphinx** from source:

    $ git clone https://github.com/RphWbr/tools_doc_sphinx
    $ cd tools_doc_sphinx
    $ pip install .


**Depedencies**

**tools_doc_sphinx** requires Python 3.6+.


Usage
-----

TODO


Support
-------

This package is developed at the LTSI Lab, INSERM-1099, located at Université Rennes 1, France.

For any enquiry, please send an email to raphael.weber@univ-rennes1.fr.

If you encounter a bug, feel free to raise an issue on [GitHub](https://github.com/RphWbr/tools_doc_sphinx/issues).


License
-------

Copyright Université Rennes 1 / INSERM (2022)

Contributor: Raphaël Weber

raphael.weber@univ-rennes1.fr

This software is a computer program whose purpose is to to provide tools for automatic generation of files used in Sphinx documentation.

This software is governed by the CeCILL license under French law and abiding by the rules of distribution of free software. You can  use, modify and/or redistribute the software under the terms of the CeCILL license as circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info". 

As a counterpart to the access to the source code and rights to copy, modify and redistribute granted by the license, users are provided only with a limited warranty  and the software's author, the holder of the economic rights, and the successive licensors have only limited liability. 

In this respect, the user's attention is drawn to the risks associated with loading, using, modifying and/or developing or reproducing the software by the user in light of its specific status of free software, that may mean that it is complicated to manipulate, and that also therefore means that it is reserved for developers and  experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the software's suitability as regards their requirements in conditions enabling the security of their systems and/or data to be ensured and, more generally, to use and operate it in the same conditions as regards security.

The fact that you are presently reading this means that you have had knowledge of the CeCILL license and that you accept its terms.

==> tools_doc_sphinx-0.1.1.tar.gz: tools_doc_sphinx-0.1.1/README.md <==
tools_doc_sphinx
================

**tools_doc_sphinx** is a package that provides functions for automatic generation of files used in Sphinx documentation :

* When documenting a Python package, generation of nested RST files with API reference,
* Generation of nested tree view of source code in a TXT file.


Documentation
-------------

Documentation is hosted on [ReadTheDocs](https://tools-doc-sphinx.readthedocs.io/en/latest/index.html).


Installation
------------

**Pip**

The easiest way is to install **ViSiAnnoT** with ``pip``:

    $ pip install tools_doc_sphinx

You may need to call ``pip3`` instead.


**From source**

You may install **tools_doc_sphinx** from source:

    $ git clone https://github.com/RphWbr/tools_doc_sphinx
    $ cd tools_doc_sphinx
    $ pip install .


**Depedencies**

**tools_doc_sphinx** requires Python 3.6+.


Support
-------

This package is developed at the LTSI Lab, INSERM-1099, located at Université Rennes 1, France.

For any enquiry, please send an email to raphael-weber@hotmail.fr.

If you encounter a bug, feel free to raise an issue on [GitHub](https://github.com/RphWbr/tools_doc_sphinx/issues).


License
-------

Copyright Université Rennes 1 / INSERM (2022)

Contributor: Raphaël Weber

raphael-weber@hotmail.fr

This software is a computer program whose purpose is to to provide tools for automatic generation of files used in Sphinx documentation.

This software is governed by the CeCILL license under French law and abiding by the rules of distribution of free software. You can  use, modify and/or redistribute the software under the terms of the CeCILL license as circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info". 

As a counterpart to the access to the source code and rights to copy, modify and redistribute granted by the license, users are provided only with a limited warranty  and the software's author, the holder of the economic rights, and the successive licensors have only limited liability. 

In this respect, the user's attention is drawn to the risks associated with loading, using, modifying and/or developing or reproducing the software by the user in light of its specific status of free software, that may mean that it is complicated to manipulate, and that also therefore means that it is reserved for developers and  experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the software's suitability as regards their requirements in conditions enabling the security of their systems and/or data to be ensured and, more generally, to use and operate it in the same conditions as regards security.

The fact that you are presently reading this means that you have had knowledge of the CeCILL license and that you accept its terms.
